
TODO: TODO_37_15_12_91: Add tests with config-only plugin which starts external process with Popen, but mock Popen by PopenMock to verify that.

To support testing with external command invocation, implement Popen mock:
*   DONE: Ability to specify calls which should be intercepted.
*   TODO: Ability to specify calls which should be passed through.
*   DONE: Raise on any unspecified calls.
